@@ -135,7 +135,7 @@ class BaseChart:
 
         interval = self.period_length / self.steps_per_period
         return FuncAnimation(
-            self.fig, self.anim_func, frames, init_func, interval=interval,
+            self.fig, self.anim_func, frames, init_func, interval=interval,blit=True
         )
 
     def calculate_new_figsize(self, real_fig: plt.figure) -> typing.List[float]:
